@@ -71,6 +71,7 @@ Conf.table <- function(x, pos = NULL, ...) {
   for(i in 1L:nrow(x)){
 
     z <- CollapseConfTab(x=x, pos=rownames(x)[i])
+    z[] <- as.double(z)
     A <- z[1, 1]; B <- z[1, 2]; C <- z[2, 1]; D <- z[2, 2]
 
     lst[[i]] <- rbind(
@@ -83,7 +84,8 @@ Conf.table <- function(x, pos = NULL, ...) {
       detrate = A / (A + B + C + D),         # detection rate
       bacc    = mean(c(A / (A + C), D / (B + D)) ),  # balanced accuracy
       fval    = Hmean(c(A / (A + B), A / (A + C)), conf.level = NA), # guetemass wollschlaeger s. 150
-      mcc     = (A*D-B*C)/sqrt((A+B)*(A+C)*(D+B)*(D+C))  # Matthews correlation coefficient (=Phi(x) with sign!)
+#   this would overflow for already small frequencies if we don't cast z to double ..
+      mcc     = (A*D-B*C) / sqrt((A+B)*(A+C)*(D+B)*(D+C))  # Matthews correlation coefficient (=Phi(x) with sign!)      
     )
   }
 
@@ -482,6 +484,7 @@ Cstat.glm <- function(x, ...) {
 
 Cstat.default <- function(x, resp, ...) {
 
+  
   # this is algorithmically clumsy and O(n^2)
   # the response ("class")
   # y <- as.numeric(factor(resp))
@@ -494,11 +497,55 @@ Cstat.default <- function(x, resp, ...) {
 
   # ... instead of elegant O(n log(n))
   # changed by 0.99.27
-  z <- .DoCount(x, as.numeric(factor(resp)))
-  return(z$C/(z$D+z$C))
+  z <- .DoCount(as.numeric(factor(resp)), x)
+  return((z$C + 0.5*z$T)/(z$D+z$C+z$T))
 
 }
 
+# alternative
+# library(rms)
+# rcorr.cens(pred, resp)
+
+
+# Example Code from:
+# https://www.listendata.com/2014/08/learn-area-under-curve-auc.html
+# 
+# # Read Data
+# df = read.csv("https://stats.idre.ucla.edu/stat/data/binary.csv")
+# 
+# # Factor Variables
+# df$admit = as.factor(df$admit)
+# df$rank = as.factor(df$rank)
+# 
+# # Logistic Model
+# df$rank <- relevel(df$rank, ref='4')
+# mylogistic <- glm(admit ~ ., data = df, family = "binomial")
+# summary(mylogistic)$coefficient
+# 
+# # Predict
+# pred = predict(mylogistic, type = "response")
+# finaldata = cbind(df, pred)
+# 
+# 
+# AUC <- function (actuals, predictedScores){
+#   fitted <- data.frame (Actuals=actuals, PredictedScores=predictedScores)
+#   colnames(fitted) <- c('Actuals','PredictedScores')
+#   ones <- fitted[fitted$Actuals==1, ] # Subset ones
+#   zeros <- fitted[fitted$Actuals==0, ] # Subsetzeros
+#   totalPairs <- nrow (ones) * nrow (zeros) # calculate total number of pairs to check
+#   conc <- sum (c(vapply(ones$PredictedScores, function(x) {((x > zeros$PredictedScores))}, FUN.VALUE=logical(nrow(zeros)))), na.rm=T)
+#   disc <- sum(c(vapply(ones$PredictedScores, function(x) {((x < zeros$PredictedScores))}, FUN.VALUE = logical(nrow(zeros)))), na.rm = T)
+#   concordance <- conc/totalPairs
+#   discordance <- disc/totalPairs
+#   tiesPercent <- (1-concordance-discordance)
+#   AUC = concordance + 0.5*tiesPercent
+#   Gini = 2*AUC - 1
+#   return(list("Concordance"=concordance, "Discordance"=discordance,
+#               "Tied"=tiesPercent, "AUC"=AUC, "Gini or Somers D"=Gini))
+# }
+# 
+# AUC(finaldata$admit, finaldata$pred)
+
 
 
 MAE <- function(x, ...) UseMethod("MAE")
@@ -957,16 +1004,16 @@ TMod <- function(..., FUN = NULL){
 }
 
 
-print.TMod <- function(x, ...){
+print.TMod <- function(x, digits=3, na.form = "-", ...){
 
   colnames(x[[1]])[-1] <- paste0(colnames(x[[1]])[-1], strrep(" ", times=4))
-  x[[1]][, -1] <- Format(x[[1]][, -1], digits=3, na.form = "-")
+  x[[1]][, -1] <- Format(x[[1]][, -1], digits=digits, na.form = na.form)
 
   x2 <- x[[2]]
-  x[[2]][, -1] <- Format(x[[2]][, -1], digits=3, na.form = "-")
+  x[[2]][, -1] <- Format(x[[2]][, -1], digits=digits, na.form = na.form)
 
   x[[2]][x[[2]]$stat %in% c("numdf", "dendf", "N"), -1] <-
-    Format(x2[x[[2]]$stat %in% c("numdf", "dendf", "N"), -1], digits=0, na.form="-")
+    Format(x2[x[[2]]$stat %in% c("numdf", "dendf", "N"), -1], digits=0, na.form=na.form)
 
   m <- rbind(x[[1]],  setNames(c("---", rep("", ncol(x[[1]]) -1)), colnames(x[[1]])),
              setNames(x[[2]], colnames(x[[1]])))
